@@ -1,8 +1,8 @@
+from py42.choices import Choices
 from py42.sdk.queries.fileevents.file_event_query import FileEventFilterStringField
-from py42.util import get_attribute_keys_from_class
 
 
-class ExposureType(FileEventFilterStringField):
+class ExposureType(FileEventFilterStringField, Choices):
     """Class that filters events based on exposure type.
 
     Available options are provided as class attributes:
@@ -14,19 +14,15 @@ class ExposureType(FileEventFilterStringField):
         - :attr:`ExposureType.IS_PUBLIC`
     """
 
-    _term = u"exposure"
+    _term = "exposure"
 
-    SHARED_VIA_LINK = u"SharedViaLink"
-    SHARED_TO_DOMAIN = u"SharedToDomain"
-    APPLICATION_READ = u"ApplicationRead"
-    CLOUD_STORAGE = u"CloudStorage"
-    REMOVABLE_MEDIA = u"RemovableMedia"
-    IS_PUBLIC = u"IsPublic"
-    OUTSIDE_TRUSTED_DOMAINS = u"OutsideTrustedDomains"
-
-    @staticmethod
-    def choices():
-        return get_attribute_keys_from_class(ExposureType)
+    SHARED_VIA_LINK = "SharedViaLink"
+    SHARED_TO_DOMAIN = "SharedToDomain"
+    APPLICATION_READ = "ApplicationRead"
+    CLOUD_STORAGE = "CloudStorage"
+    REMOVABLE_MEDIA = "RemovableMedia"
+    IS_PUBLIC = "IsPublic"
+    OUTSIDE_TRUSTED_DOMAINS = "OutsideTrustedDomains"
 
 
 class ProcessName(FileEventFilterStringField):
@@ -34,7 +30,7 @@ class ProcessName(FileEventFilterStringField):
     ``read by browser or other app`` events only).
     """
 
-    _term = u"processName"
+    _term = "processName"
 
 
 class ProcessOwner(FileEventFilterStringField):
@@ -42,7 +38,7 @@ class ProcessOwner(FileEventFilterStringField):
     (applies to ``read by browser or other app`` events only).
     """
 
-    _term = u"processOwner"
+    _term = "processOwner"
 
 
 class RemovableMediaName(FileEventFilterStringField):
@@ -50,7 +46,7 @@ class RemovableMediaName(FileEventFilterStringField):
     (applies to ``removable media`` events only).
     """
 
-    _term = u"removableMediaName"
+    _term = "removableMediaName"
 
 
 class RemovableMediaVendor(FileEventFilterStringField):
@@ -58,7 +54,7 @@ class RemovableMediaVendor(FileEventFilterStringField):
     exposure (applies to ``removable media`` events only).
     """
 
-    _term = u"removableMediaVendor"
+    _term = "removableMediaVendor"
 
 
 class RemovableMediaMediaName(FileEventFilterStringField):
@@ -67,7 +63,7 @@ class RemovableMediaMediaName(FileEventFilterStringField):
     ``removable media`` events only).
     """
 
-    _term = u"removableMediaMediaName"
+    _term = "removableMediaMediaName"
 
 
 class RemovableMediaVolumeName(FileEventFilterStringField):
@@ -76,7 +72,7 @@ class RemovableMediaVolumeName(FileEventFilterStringField):
     ``removable media`` events only).
     """
 
-    _term = u"removableMediaVolumeName"
+    _term = "removableMediaVolumeName"
 
 
 class RemovableMediaPartitionID(FileEventFilterStringField):
@@ -84,7 +80,7 @@ class RemovableMediaPartitionID(FileEventFilterStringField):
     to the removable media involved in the exposure (applies to ``removable media`` events only).
     """
 
-    _term = u"removableMediaPartitionId"
+    _term = "removableMediaPartitionId"
 
 
 class RemovableMediaSerialNumber(FileEventFilterStringField):
@@ -92,10 +88,10 @@ class RemovableMediaSerialNumber(FileEventFilterStringField):
     by the operating system (applies to ``removable media`` events only).
     """
 
-    _term = u"removableMediaSerialNumber"
+    _term = "removableMediaSerialNumber"
 
 
-class SyncDestination(FileEventFilterStringField):
+class SyncDestination(FileEventFilterStringField, Choices):
     """Class that filters events based on the name of the cloud service the file is synced with
     (applies to ``synced to cloud service`` events only).
 
@@ -109,19 +105,15 @@ class SyncDestination(FileEventFilterStringField):
         - :attr:`SyncDestination.ONEDRIVE`
     """
 
-    _term = u"syncDestination"
+    _term = "syncDestination"
 
-    ICLOUD = u"ICloud"
-    BOX = u"Box"
-    BOX_DRIVE = u"BoxDrive"
-    GOOGLE_DRIVE = u"GoogleDrive"
-    GOOGLE_BACKUP_AND_SYNC = u"GoogleBackupAndSync"
-    DROPBOX = u"Dropbox"
-    ONEDRIVE = u"OneDrive"
-
-    @staticmethod
-    def choices():
-        return get_attribute_keys_from_class(SyncDestination)
+    ICLOUD = "ICloud"
+    BOX = "Box"
+    BOX_DRIVE = "BoxDrive"
+    GOOGLE_DRIVE = "GoogleDrive"
+    GOOGLE_BACKUP_AND_SYNC = "GoogleBackupAndSync"
+    DROPBOX = "Dropbox"
+    ONEDRIVE = "OneDrive"
 
 
 class SyncDestinationUsername(FileEventFilterStringField):
@@ -129,7 +121,7 @@ class SyncDestinationUsername(FileEventFilterStringField):
     the file is synced with (applies to ``synced to cloud service`` events only).
     """
 
-    _term = u"syncDestinationUsername"
+    _term = "syncDestinationUsername"
 
 
 class TabURL(FileEventFilterStringField):
@@ -137,7 +129,7 @@ class TabURL(FileEventFilterStringField):
     contents were read by the browser (applies to ``read by browser or other app`` events only).
     """
 
-    _term = u"tabUrls"
+    _term = "tabUrls"
 
 
 class WindowTitle(FileEventFilterStringField):
@@ -146,4 +138,4 @@ class WindowTitle(FileEventFilterStringField):
     events only).
     """
 
-    _term = u"tabTitles"
+    _term = "tabTitles"
