@@ -4,10 +4,10 @@ from py42.sdk.queries.fileevents.file_event_query import FileEventFilterStringFi
 class Printer(FileEventFilterStringField):
     """Class that filters events by printer name."""
 
-    _term = u"printerName"
+    _term = "printerName"
 
 
 class PrintJobName(FileEventFilterStringField):
     """Class that filters events by print job name."""
 
-    _term = u"printJobName"
+    _term = "printJobName"
